@@ -1,13 +1,10 @@
 """ Abstract factory module """
-from abc import ABC, abstractmethod
 from enum import Enum
+from typing import Protocol
 from databus.dispatcher.abstract_dispatcher import AbstractDispatcher, DispatcherTicket
 
-
-
 class DispatcherCreationError(Exception):
     """ Dispatcher creation exception """
-
     class ErrorCode(Enum):
         """ Error code """
         cant_create_instance: 1
@@ -26,12 +23,11 @@ class DispatcherCreationError(Exception):
     def message(self) -> str:
         """ Error message """
         if self.error_code == DispatcherCreationError.ErrorCode.cant_create_instance:
-            return "Can't create " + self.module + " dispatcher instance"
+            return f"Can't create {self.module} dispatcher instance"
         return "Dispatcher creation error"
 
 
-class AbstractDispatcherFactory(ABC): # pylint: disable=R0903
+class AbstractDispatcherFactory(Protocol): # pylint: disable=R0903
     """ Abstract dispatcher factory class """
-    @abstractmethod
     def create_dispatcher(self, p_module: str, p_ticket: DispatcherTicket) -> AbstractDispatcher:
         """ Creates a new dispatcher """
