@@ -12,7 +12,7 @@ class DemoPuller2(AbstractPuller):
         """ Fake operation """
         for seated_passenger in p_seated_passengers:
             self.log.append_text(
-                "Demo puller 2 notified about seated passenger " + seated_passenger.id_text)
+                f"Demo puller 2 notified about seated passenger {seated_passenger.id_text}")
 
     def pull(self) -> List[DemoPassenger2]:
         """ Fake operation """
@@ -24,7 +24,7 @@ class DemoPuller2(AbstractPuller):
         passenger1.source_system = "DEMO_SYSTEM"
         passenger1.puller_module = self.__module__
         output.append(passenger1)
-        self.log.append_text("Got passenger " + passenger1.id_text)
+        self.log.append_text(f"Got passenger {passenger1.id_text}")
 
         passenger2 = DemoPassenger2()
         passenger2.external_id = "ID_2_2"
@@ -32,6 +32,6 @@ class DemoPuller2(AbstractPuller):
         passenger2.source_system = "DEMO_SYSTEM"
         passenger2.puller_module = self.__module__
         output.append(passenger2)
-        self.log.append_text("Got passenger " + passenger2.id_text)
+        self.log.append_text(f"Got passenger {passenger2.id_text}")
 
         return output
